

#ifndef SENSORMANAGER_H
#define SENSORMANAGER_H

#include "mbed.h"
#include "Mail.h"
#include "EventFlags.h"
#include "CommonStructures.h"
#include "LSM9DS0.h"

using namespace rtos;

class SensorManager {
    private:
        // Flags hold ready state
        // 0x0*1 means timer ready (tick)
        // 0x01* means data ready (LSM9DRP = HIGH)
        EventFlags* sensor_flags;
        // Mailbox for output state data
        Mail<VehicleState, 16>* sensor_tx;
        // Sensor handle
        LSM9DS0 lsm;
        // Allocate store for tait_bryan angles to save memory
        float tait_bryan[3];
        // Convert a gyro quaternion to Tait-Bryan angles.
        static void quaternion_to_tait_bryan(float* output, float q0, float q1, float q2, float q3);

    public:
        SensorManager(EventFlags* sensor_events, Mail<VehicleState, 16>* state_output_mailbox);
        void run();
        static void sensor_dready_rising_isr(EventFlags* sensor_events);
        static void sensor_timer_tick_isr(EventFlags* sensor_events);
};

#endif